using UnityEngine;

namespace AnimatedWeapons
{
    public class Mod
    {
        public const string Tag = " -AW+";

        public static void Main()
        {
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("Glock 17"),
                NameOverride = $"Makarov{Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/MakarovIcon.png"),
                AfterSpawn = (instance) =>
                {
                    ModAPI.KeepExtraObjects();
                    instance.transform.Find("Slide").GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/MakarovSlide.png");

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/MakarovCol.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/Makarov.png");

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.barrelPosition = new Vector2(0.15f, 0.08f);
                    firearm.casingPosition = new Vector2(-0.0742f, 0.0855f);
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/Makarov.mp3")
                    };

                    var cartridge = ModAPI.FindCartridge("9mm");
                    cartridge.name = "Makarov";
                    cartridge.Damage = 5f;
                    cartridge.Recoil = 0.1f;
                    cartridge.ImpactForce = 0.1f;
                    firearm.Cartridge = cartridge;
		        }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("Glock 17"),
                NameOverride = $"Colt M1911{Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/ColtM1911Icon.png"),
                AfterSpawn = (instance) =>
                {
                    ModAPI.KeepExtraObjects();
                    instance.transform.Find("Slide").GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/Colt M1911Slide.png");

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/ColtM1911Col.png", 10);
                    instance.FixColliders();
                    instance.AddComponent<RandomSpriteBehaviour>().sprites = new Sprite[]
                    {
                        ModAPI.LoadSprite("Textures/Colt M1911.png"),
                        ModAPI.LoadSprite("Textures/Colt M1911 2.png"),
                    };

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.casingPosition = new Vector2(-0.052f, 0.0814f);
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/ColtM1911.mp3")
                    };

                    var cartridge = ModAPI.FindCartridge("9mm");
                    cartridge.name = "Colt M1911";
                    cartridge.Damage = 9f;
                    cartridge.Recoil = 0.2f;
                    cartridge.ImpactForce = 0.1f;
                    firearm.Cartridge = cartridge;
		        }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("Shotgun"),
                NameOverride = $"Remington 870{Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/Remington870Icon.png"),
                AfterSpawn = (instance) =>
                {
                    ModAPI.KeepExtraObjects();
                    var slide = instance.transform.Find("Slide");
                    slide.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/Remington 870Slide.png");
                    slide.GetComponent<SpriteRenderer>().color = Color.white;
                    slide.localScale = new Vector3(1f, 1f);
                    Object.Destroy(instance.transform.Find("Cover").gameObject);

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/Remington870Col.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/Remington 870.png");  

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.BulletsPerShot = 6;
                    firearm.barrelPosition = new Vector2(0.644f, 0.0554f);
                    firearm.casingPosition = new Vector2(-0.09f, 0.094f);
                    firearm.InitialInaccuracy = 0.2f;
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/Remington 870.mp3"),
                    };

                    var cartridge = ModAPI.FindCartridge("5.56x45mm");
                    cartridge.name = "Remington 870";
                    cartridge.Damage = 18f;
                    cartridge.Recoil = 0.3f;
                    cartridge.ImpactForce = 0.2f;
                    firearm.Cartridge = cartridge;
		        }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("Shotgun"),
                NameOverride = $"Remington 870 (Wooden Skin){Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/Remington870(WoodSkin)Icon.png"),
                AfterSpawn = (instance) =>
                {
                    ModAPI.KeepExtraObjects();
                    var slide = instance.transform.Find("Slide");
                    slide.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/Remington870(WoodSkin)Slide.png");
                    slide.GetComponent<SpriteRenderer>().color = Color.white;
                    slide.localScale = new Vector3(1f, 1f);
                    Object.Destroy(instance.transform.Find("Cover").gameObject);

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/Remington870Col.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/Remington 870 (Wood Skin).png");  

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.BulletsPerShot = 6;
                    firearm.barrelPosition = new Vector2(0.644f, 0.0554f);
                    firearm.casingPosition = new Vector2(-0.09f, 0.094f);
                    firearm.InitialInaccuracy = 0.2f;
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/Remington 870.mp3")
                    };

                    var cartridge = ModAPI.FindCartridge("5.56x45mm");
                    cartridge.name = "Remington 870";
                    cartridge.Damage = 18f;
                    cartridge.Recoil = 0.3f;
                    cartridge.ImpactForce = 0.2f;
                    firearm.Cartridge = cartridge;
		        }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("Glock 17"),
                NameOverride = $"HK USP-S{Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/USP-SIcon.png"),
                AfterSpawn = (instance) =>
                {
                    ModAPI.KeepExtraObjects();
                    instance.transform.Find("Slide").GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/USP-SSlide.png");

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/USP-SCol.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/USP-S.png");

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.BulletsPerShot = 1;
                    firearm.barrelPosition = new Vector2(0.38f, 0.08f);
                    firearm.casingPosition = new Vector2(-0.2466f, 0.1034f);
                    firearm.ShotSounds = new AudioClip[]
                    {
                        ModAPI.LoadSound("Sounds/USP-S.mp3"),
                    };

                    var cartridge = ModAPI.FindCartridge("9mm");
                    cartridge.name = "USP-S";
                    cartridge.Damage = 7f;
                    cartridge.Recoil = 0.1f;
                    cartridge.ImpactForce = 0.1f;
                    firearm.Cartridge = cartridge;
		        }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("M1 Garand"),
                NameOverride = $"RPD{Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/RPDIcon.png"),
                AfterSpawn = (instance) =>
                {
                    ModAPI.KeepExtraObjects();
                    var slideRenderer = instance.transform.Find("Slide").GetComponent<SpriteRenderer>();
                    slideRenderer.sprite = ModAPI.LoadSprite("Textures/RPDSlide.png");
                    slideRenderer.sortingOrder = instance.GetComponent<SpriteRenderer>().sortingOrder + 1;

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/RPDCol.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/RPD.png");

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.barrelPosition = new Vector2(0.849f, 0.14f);
                    firearm.casingPosition = new Vector2(-0.0559f, 0.128f);
                    firearm.InitialInaccuracy = 0.05f;
                    firearm.Automatic = true;
                    firearm.AutomaticFireInterval = 0.1f;
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/RPD.mp3"),
                    };

                    var cartridge = ModAPI.FindCartridge("7.62x39mm");
                    cartridge.name = "RPD";
                    cartridge.Damage = 26f;
                    cartridge.Recoil = 0.2f;
                    cartridge.ImpactForce = 0.4f;
                    firearm.Cartridge = cartridge;
		        }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("M1 Garand"),
                NameOverride = $"RPK{Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/RPKIcon.png"),
                AfterSpawn = (instance) =>
                {
                    ModAPI.KeepExtraObjects();
                    var slideRenderer = instance.transform.Find("Slide").GetComponent<SpriteRenderer>();
                    slideRenderer.sprite = ModAPI.LoadSprite("Textures/RPKSlide.png");
                    slideRenderer.sortingOrder = instance.GetComponent<SpriteRenderer>().sortingOrder + 1;

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/RPKCol.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/RPK.png");

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.barrelPosition = new Vector2(0.75f, 0.125f);
                    firearm.casingPosition = new Vector2(-0.0751f, 0.1864f);
                    firearm.InitialInaccuracy = 0.05f;
                    firearm.Automatic = true;
                    firearm.AutomaticFireInterval = 0.1f;
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/RPK.mp3")
                    };

                    var cartridge = ModAPI.FindCartridge("7.62x39mm");
                    cartridge.name = "RPK";
                    cartridge.Damage = 27f;
                    cartridge.Recoil = 0.1f;
                    cartridge.ImpactForce = 0.3f;
                    firearm.Cartridge = cartridge;
		        }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("M1 Garand"),
                NameOverride = $"SVD{Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/SVDIcon.png"),
                AfterSpawn = (instance) =>
                {
                    ModAPI.KeepExtraObjects();

                    var slideRenderer = instance.transform.Find("Slide").GetComponent<SpriteRenderer>();
                    slideRenderer.sprite = ModAPI.LoadSprite("Textures/SVDSlide.png");
                    slideRenderer.sortingOrder = instance.GetComponent<SpriteRenderer>().sortingOrder + 1;

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/SVDCol.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/SVD.png");

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.barrelPosition = new Vector2(0.84f, 0.0358f);
                    firearm.casingPosition = new Vector2(-0.1445f, 0.0599f);
                    firearm.InitialInaccuracy = 0f;
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/SVD.mp3")
                    };

                    var cartridge = ModAPI.FindCartridge("50 BMG");
                    cartridge.name = "SVD";
                    cartridge.Damage = 65f;
                    cartridge.Recoil = 0.2f;
                    cartridge.ImpactForce = 0.24f;
                    firearm.Cartridge = cartridge;
		        }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("Pistol"),
                NameOverride = $"AWP{Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/AWPIcon.png"),
                AfterSpawn = (instance) =>
                {
                    ModAPI.KeepExtraObjects();
                    instance.transform.Find("Slide").GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/AWPSlide.png");

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/AWPCol.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/AWP.png");

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.barrelPosition = new Vector2(0.95f, 0.048f);
                    firearm.casingPosition = new Vector2(-0.414f, 0.0566f);
                    firearm.InitialInaccuracy = 0f;
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/AWP.mp3")
                    };

                    var cartridge = ModAPI.FindCartridge("50 BMG");
                    cartridge.name = "AWP";
                    cartridge.Damage = 90f;
                    cartridge.Recoil = 0.4f;
                    cartridge.ImpactForce = 0.5f;
                    firearm.Cartridge = cartridge;
		        }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("M1 Garand"),
                NameOverride = $"Thompson{Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/ThompsonIcon.png"),
                AfterSpawn = (instance) =>
                {
                    ModAPI.KeepExtraObjects();
                    var slideRenderer = instance.transform.Find("Slide").GetComponent<SpriteRenderer>();
                    slideRenderer.sprite = ModAPI.LoadSprite("Textures/ThompsonSlide.png");
                    slideRenderer.sortingOrder = instance.GetComponent<SpriteRenderer>().sortingOrder + 1;

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/ThompsonCol.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/Thompson.png");

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.barrelPosition = new Vector2(0.564f, 0.144f);
                    firearm.casingPosition = new Vector2(0.059f, 0.1613f);
                    firearm.InitialInaccuracy = 0.03f;
                    firearm.Automatic = true;
                    firearm.AutomaticFireInterval = 0.1f;
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/Thompson.mp3")
                    };

                    var cartridge = ModAPI.FindCartridge("9mm");
                    cartridge.name = "Thompson";
                    cartridge.Damage = 10f;
                    cartridge.Recoil = 0.2f;
                    cartridge.ImpactForce = 0.1f;
                    firearm.Cartridge = cartridge;
		        }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("Assault Rifle"),
                NameOverride = $"HK XM8{Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/XM8Icon.png"),
                AfterSpawn = (instance) =>
                {
                    ModAPI.KeepExtraObjects();

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/XM8Col.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/XM8.png");

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.barrelPosition = new Vector2(0.65f, 0.076f);
                    firearm.casingPosition = new Vector2(-0.0713f, 0.1004f);
                    firearm.InitialInaccuracy = 0.01f;
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/XM8.mp3")
                    };

                    var cartridge = ModAPI.FindCartridge("5.56x45mm");
                    cartridge.name = "XM8";
                    cartridge.Damage = 15f;
                    cartridge.Recoil = 0.3f;
                    cartridge.ImpactForce = 0.1f;
                    firearm.Cartridge = cartridge;
                }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("Assault Rifle"),
                NameOverride = $"HK416{Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/HK416Icon.png"),
                AfterSpawn = (instance) =>
                {
                    ModAPI.KeepExtraObjects();

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/HK416Col.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/HK416.png");

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.InitialInaccuracy = 0.003f;
                    firearm.barrelPosition = new Vector2(0.53f, 0.102f);
                    firearm.casingPosition = new Vector2(-0.0732f, 0.1005f);
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/HK416.mp3")
                    };

                    var cartridge = ModAPI.FindCartridge("5.56x45mm");
                    cartridge.name = "HK416";
                    cartridge.Damage = 14f;
                    cartridge.Recoil = 0.3f;
                    cartridge.ImpactForce = 0.1f;
                    firearm.Cartridge = cartridge;
		        }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("Assault Rifle"),
                NameOverride = $"FN FAL{Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/FN FALIcon.png"),
                AfterSpawn = (instance) =>
                {
                    ModAPI.KeepExtraObjects();

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/FNFALCol.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/FN FAL.png");

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.barrelPosition = new Vector2(0.5706f, 0.0912f);
                    firearm.casingPosition = new Vector2(-0.0725f, 0.1005f);
                    firearm.InitialInaccuracy = 0.007f;
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/FNFAL.mp3")
                    };

                    var cartridge = ModAPI.FindCartridge("7.62x51mm");
                    cartridge.name = "FN FAL";
                    cartridge.Damage = 15f;
                    cartridge.Recoil = 0.2f;
                    cartridge.ImpactForce = 0.1f;
                    firearm.Cartridge = cartridge;
                }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("M1 Garand"),
                NameOverride = $"TEC-9{Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/TEC-9Icon.png"),
                AfterSpawn = (instance) =>
                {
                    var cover = new GameObject("Cover");
                    cover.transform.SetParent(instance.transform);
                    cover.transform.localPosition = Vector3.zero;
                    cover.transform.localRotation = Quaternion.identity;
                    cover.transform.localScale = Vector3.one;
                    var coverRenderer = cover.AddComponent<SpriteRenderer>();
                    coverRenderer.sprite = ModAPI.LoadSprite("Textures/TEC-9Cover.png");
                    coverRenderer.sortingOrder = 7;

                    ModAPI.KeepExtraObjects();
                    var slideRenderer = instance.transform.Find("Slide").GetComponent<SpriteRenderer>();
                    slideRenderer.sprite = ModAPI.LoadSprite("Textures/TEC-9Slide.png");
                    slideRenderer.sortingOrder = instance.GetComponent<SpriteRenderer>().sortingOrder + 1;

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/TEC-9Col.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/TEC-9.png");

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.barrelPosition = new Vector2(0.223f, 0.11f);
                    firearm.casingPosition = new Vector2(0.0319f, 0.1002f);
                    firearm.InitialInaccuracy = 0.008f;
                    firearm.Automatic = true;
                    firearm.AutomaticFireInterval = 0.1689f;
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/TEC-9.mp3")
                    };

                    var cartridge = ModAPI.FindCartridge("9mm");
                    cartridge.name = "TEC-9";
                    cartridge.Damage = 8f;
                    cartridge.Recoil = 0.1f;
                    cartridge.ImpactForce = 0.1f;
                    firearm.Cartridge = cartridge;
		        }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("Shotgun"),
                NameOverride = $"AA-12{Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/AA-12Icon.png"),
                AfterSpawn = (instance) =>
                {
                    ModAPI.KeepExtraObjects();
                    var slide = instance.transform.Find("Slide");
                    slide.localScale = new Vector3(1f, 1f);
                    var slideRenderer = slide.GetComponent<SpriteRenderer>();
                    slideRenderer.sprite = ModAPI.LoadSprite("Textures/AA-12Slide.png");
                    slideRenderer.color = Color.white;

                    var cover = instance.transform.Find("Cover");
                    cover.localScale = new Vector3(1f, 1f);
                    var coverRenderer = cover.GetComponent<SpriteRenderer>();
                    coverRenderer.sprite = ModAPI.LoadSprite("Textures/AA-12Cover.png");
                    coverRenderer.color = Color.white;
                    coverRenderer.sortingOrder = 7;

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/AA-12Col.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/AA-12.png");

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.BulletsPerShot = 6;
                    firearm.barrelPosition = new Vector2(0.6256f, 0.078f);
                    firearm.casingPosition = new Vector2(0f, 0.0716f);
                    firearm.InitialInaccuracy = 0.1f;
                    firearm.Automatic = true;
                    firearm.AutomaticFireInterval = 0.304f;
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/AA-12.mp3")
                    };

                    var cartridge = ModAPI.FindCartridge("7.62x51mm");
                    cartridge.name = "AA-12";
                    cartridge.Damage = 19f;
                    cartridge.Recoil = 0.2f;
                    cartridge.ImpactForce = 0.2f;
                    firearm.Cartridge = cartridge;
                }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("M1 Garand"),
                NameOverride = $"HK MP7{Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/MP7Icon.png"),
                AfterSpawn = (instance) =>
                {
                    var cover = new GameObject("Cover");
                    cover.transform.SetParent(instance.transform);
                    cover.transform.localPosition = Vector3.zero;
                    cover.transform.localRotation = Quaternion.identity;
                    cover.transform.localScale = Vector3.one;
                    var coverRenderer = cover.AddComponent<SpriteRenderer>();
                    coverRenderer.sprite = ModAPI.LoadSprite("Textures/MP7Cover.png");
                    coverRenderer.sortingOrder = 7;

                    ModAPI.KeepExtraObjects();
                    var slideRenderer = instance.transform.Find("Slide").GetComponent<SpriteRenderer>();
                    slideRenderer.sprite = ModAPI.LoadSprite("Textures/MP7Slide.png");
                    slideRenderer.sortingOrder = instance.GetComponent<SpriteRenderer>().sortingOrder + 1;

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/MP7Col.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/MP7.png");

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.barrelPosition = new Vector2(0.318f, 0.08f);
                    firearm.casingPosition = new Vector2(-0.072f, 0.0857f);
                    firearm.Automatic = true;
                    firearm.AutomaticFireInterval = 0.0867f;
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/MP7.mp3")
                    };

                    var cartridge = ModAPI.FindCartridge("9mm");
                    cartridge.name = "MP7";
                    cartridge.Damage = 8f;
                    cartridge.Recoil = 0.1f;
                    cartridge.ImpactForce = 0.1f;
                    firearm.Cartridge = cartridge;
		        }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("Pistol"),
                NameOverride = $"Beretta 92 (Silver Skin){Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/Beretta92SilverIcon.png"),
                AfterSpawn = (instance) =>
                {
                    ModAPI.KeepExtraObjects();
                    instance.transform.Find("Slide").GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/Beretta92SilverSlide.png");

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/Beretta92Col.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/Beretta92Silver.png");

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.barrelPosition = new Vector2(0.161f, 0.064f);
                    firearm.casingPosition = new Vector2(-0.094f, 0.07f);
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/Beretta92.mp3")
                    };

                    var cartridge = ModAPI.FindCartridge("9mm");
                    cartridge.name = "Beretta 92";
                    cartridge.Damage = 8f;
                    cartridge.Recoil = 0.1f;
                    cartridge.ImpactForce = 0.1f;
                    firearm.Cartridge = cartridge;
		        }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("Pistol"),
                NameOverride = $"Beretta 92 (Black Skin){Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/Beretta92BlackIcon.png"),
                AfterSpawn = (instance) =>
                {
                    ModAPI.KeepExtraObjects();
                    instance.transform.Find("Slide").GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/Beretta92BlackSlide.png");

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/Beretta92Col.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/Beretta92Black.png");

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.barrelPosition = new Vector2(0.161f, 0.064f);
                    firearm.casingPosition = new Vector2(-0.094f, 0.07f);
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/Beretta92.mp3")
                    };

                    var cartridge = ModAPI.FindCartridge("9mm");
                    cartridge.name = "Beretta 92";
                    cartridge.Damage = 8f;
                    cartridge.Recoil = 0.1f;
                    cartridge.ImpactForce = 0.1f;
                    firearm.Cartridge = cartridge;
		        }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("M1 Garand"),
                NameOverride = $"Ingram MAC-10{Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/MAC-10Icon.png"),
                AfterSpawn = (instance) =>
                {
                    var cover = new GameObject("Cover");
                    cover.transform.SetParent(instance.transform);
                    cover.transform.localPosition = new Vector3(0f, 0f);
                    cover.transform.localRotation = Quaternion.identity;
                    cover.transform.localScale = new Vector3(1f, 1f);
                    var coverRenderer = cover.AddComponent<SpriteRenderer>();
                    coverRenderer.sprite = ModAPI.LoadSprite("Textures/MAC-10Cover.png");
                    coverRenderer.sortingOrder = 7;

                    ModAPI.KeepExtraObjects();
                    var slideRenderer = instance.transform.Find("Slide").GetComponent<SpriteRenderer>();
                    slideRenderer.sprite = ModAPI.LoadSprite("Textures/MAC-10Slide.png");
                    slideRenderer.sortingOrder = instance.GetComponent<SpriteRenderer>().sortingOrder + 1;

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/MAC-10Col.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/MAC-10.png");

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.barrelPosition = new Vector2(0.326f, 0.16f);
                    firearm.casingPosition = new Vector2(-0.0424f, 0.1585f);
                    firearm.InitialInaccuracy = 0.0999f;
                    firearm.Automatic = true;
                    firearm.AutomaticFireInterval = 0.0712f;
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/MAC-10.mp3")
                    };

                    var cartridge = ModAPI.FindCartridge("9mm");
                    cartridge.name = "MAC-10";
                    cartridge.Damage = 12f;
                    cartridge.Recoil = 0.1f;
                    cartridge.ImpactForce = 0.2f;
                    firearm.Cartridge = cartridge;
		        }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("Pistol"),
                NameOverride = $"FN Five-seveN{Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/FN Five-seveNIcon.png"),
                AfterSpawn = (instance) =>
                {
                    ModAPI.KeepExtraObjects();
                    instance.transform.Find("Slide").GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/FN Five-seveNSlide.png");

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/FNFive-seveNCol.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/FN Five-seveN.png");

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.barrelPosition = new Vector2(0.15f, 0.08f);
                    firearm.casingPosition = new Vector2(-0.107f, 0.086f);
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/FN Five-seveN.mp3")
                    };

                    var cartridge = ModAPI.FindCartridge("9mm");
                    cartridge.name = "FN Five-seveN";
                    cartridge.Damage = 8f;
                    cartridge.Recoil = 0.2f;
                    cartridge.ImpactForce = 0.1f;
                    firearm.Cartridge = cartridge;
		        }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("M1 Garand"),
                NameOverride = $"FAMAS{Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/FAMASIcon.png"),
                AfterSpawn = (instance) =>
                {
                    var cover = new GameObject("Cover");
                    cover.transform.SetParent(instance.transform);
                    cover.transform.localPosition = Vector3.zero;
                    cover.transform.localRotation = Quaternion.identity;
                    cover.transform.localScale = Vector3.one;
                    var coverRenderer = cover.AddComponent<SpriteRenderer>();
                    coverRenderer.sprite = ModAPI.LoadSprite("Textures/FAMASCover.png");
                    coverRenderer.sortingOrder = 7;

                    ModAPI.KeepExtraObjects();
                    var slideRenderer = instance.transform.Find("Slide").GetComponent<SpriteRenderer>();
                    slideRenderer.sprite = ModAPI.LoadSprite("Textures/FAMASSlide.png");
                    slideRenderer.sortingOrder = instance.GetComponent<SpriteRenderer>().sortingOrder + 1;

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/FAMASCol.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/FAMAS.png");

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.barrelPosition = new Vector2(0.65f, 0.067f);
                    firearm.casingPosition = new Vector2(-0.298f, 0.07f);
                    firearm.InitialInaccuracy = 0.01f;
                    firearm.Automatic = true;
                    firearm.AutomaticFireInterval = 0.085f;
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/FAMAS.mp3")
                    };

                    var cartridge = ModAPI.FindCartridge("7.62x51mm");
                    cartridge.name = "FAMAS";
                    cartridge.Damage = 14f;
                    cartridge.Recoil = 0.1f;
                    cartridge.ImpactForce = 0.1f;
                    firearm.Cartridge = cartridge;
		        }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("M1 Garand"),
                NameOverride = $"HK UMP 45{Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/UMP45Icon.png"),
                AfterSpawn = (instance) =>
                {
                    var cover = new GameObject("Cover");
                    cover.transform.SetParent(instance.transform);
                    cover.transform.localPosition = new Vector3(0f, 0f);
                    cover.transform.localRotation = Quaternion.identity;
                    cover.transform.localScale = new Vector3(1f, 1f);
                    var coverRenderer = cover.AddComponent<SpriteRenderer>();
                    coverRenderer.sprite = ModAPI.LoadSprite("Textures/UMP45Cover.png");
                    coverRenderer.sortingOrder = 7;

                    ModAPI.KeepExtraObjects();
                    var slideRenderer = instance.transform.Find("Slide").GetComponent<SpriteRenderer>();
                    slideRenderer.sprite = ModAPI.LoadSprite("Textures/UMP45Slide.png");
                    slideRenderer.sortingOrder = instance.GetComponent<SpriteRenderer>().sortingOrder + 1;

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/UMP45Col.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/UMP45.png");

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.barrelPosition = new Vector2(0.48f, 0.117f);
                    firearm.casingPosition = new Vector2(0.1154f, 0.1438f);
                    firearm.InitialInaccuracy = 0.02f;
                    firearm.Automatic = true;
                    firearm.AutomaticFireInterval = 0.0798f;
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/UMP45.mp3")
                    };

                    var cartridge = ModAPI.FindCartridge("9mm");
                    cartridge.name = "UMP45";
                    cartridge.Damage = 7f;
                    cartridge.Recoil = 0.1f;
                    cartridge.ImpactForce = 0.1f;
                    firearm.Cartridge = cartridge;
		        }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("M1 Garand"),
                NameOverride = $"Galil{Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/GalilIcon.png"),
                AfterSpawn = (instance) =>
                {
                    ModAPI.KeepExtraObjects();
                    var slideRenderer = instance.transform.Find("Slide").GetComponent<SpriteRenderer>();
                    slideRenderer.sprite = ModAPI.LoadSprite("Textures/GalilSlide.png");
                    slideRenderer.sortingOrder = instance.GetComponent<SpriteRenderer>().sortingOrder + 1;

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/GalilCol.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/Galil.png");

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.barrelPosition = new Vector2(0.6299f, 0.1f);
                    firearm.casingPosition = new Vector2(-0.0279f, 0.0998f);
                    firearm.InitialInaccuracy = 0.03f;
                    firearm.Automatic = true;
                    firearm.AutomaticFireInterval = 0.0899f;
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/Galil.mp3")
                    };

                    var cartridge = ModAPI.FindCartridge("7.62x51mm");
                    cartridge.name = "Galil";
                    cartridge.Damage = 24f;
                    cartridge.Recoil = 0.1f;
                    cartridge.ImpactForce = 0.1f;
                    firearm.Cartridge = cartridge;
		        }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("M1 Garand"),
                NameOverride = $"StG 44{Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/StG44Icon.png"),
                AfterSpawn = (instance) =>
                {
                    var cover = new GameObject("Cover");
                    cover.transform.SetParent(instance.transform);
                    cover.transform.localPosition = new Vector3(0f, 0f);
                    cover.transform.localRotation = Quaternion.identity;
                    cover.transform.localScale = new Vector3(1f, 1f);
                    var coverRenderer = cover.AddComponent<SpriteRenderer>();
                    coverRenderer.sprite = ModAPI.LoadSprite("Textures/StG44Cover.png");
                    coverRenderer.sortingOrder = 7;

                    ModAPI.KeepExtraObjects();
                    var slideRenderer = instance.transform.Find("Slide").GetComponent<SpriteRenderer>();
                    slideRenderer.sprite = ModAPI.LoadSprite("Textures/StG44Slide.png");
                    slideRenderer.sortingOrder = instance.GetComponent<SpriteRenderer>().sortingOrder + 1;

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/StG44Col.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/StG44.png");

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.barrelPosition = new Vector2(0.632f, 0.116f);
                    firearm.casingPosition = new Vector2(-0.0157f, 0.114f);
                    firearm.InitialInaccuracy = 0.02f;
                    firearm.Automatic = true;
                    firearm.AutomaticFireInterval = 0.0899f;
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/StG44.mp3")
                    };

                    var cartridge = ModAPI.FindCartridge("7.62x39mm");
                    cartridge.name = "StG 44";
                    cartridge.Damage = 21f;
                    cartridge.Recoil = 0.1f;
                    cartridge.ImpactForce = 0.1f;
                    firearm.Cartridge = cartridge;
		        }
            });
            ModAPI.Register(new Modification
            {
                OriginalItem = ModAPI.FindSpawnable("M1 Garand"),
                NameOverride = $"PKM{Tag}",
                NameToOrderByOverride = " ",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("Firearms"),
                ThumbnailOverride = ModAPI.LoadSprite("Textures/PKMIcon.png"),
                AfterSpawn = (instance) =>
                {
                    ModAPI.KeepExtraObjects();
                    var slideRenderer = instance.transform.Find("Slide").GetComponent<SpriteRenderer>();
                    slideRenderer.sprite = ModAPI.LoadSprite("Textures/PKMSlide.png");
                    slideRenderer.sortingOrder = instance.GetComponent<SpriteRenderer>().sortingOrder + 1;

                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Colliders/PKMCol.png", 10);
                    instance.FixColliders();
                    instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Textures/PKM.png");

                    var firearm = instance.GetComponent<FirearmBehaviour>();
                    firearm.barrelPosition = new Vector2(0.96f, 0.16f);
                    firearm.casingPosition = new Vector2(-0.343f, 0.129f);
                    firearm.InitialInaccuracy = 0.04f;
                    firearm.Automatic = true;
                    firearm.AutomaticFireInterval = 0.085f;
                    firearm.ShotSounds = new[]
                    {
                        ModAPI.LoadSound("Sounds/PKM.mp3")
                    };

                    var cartridge = ModAPI.FindCartridge("7.62x39mm");
                    cartridge.name = "PKM";
                    cartridge.Damage = 29f;
                    cartridge.Recoil = 0.2f;
                    cartridge.ImpactForce = 0.2f;
                    firearm.Cartridge = cartridge;
		        }
            });
        }
    }
}
// Originally uploaded by 'Mishanya'. Do not reupload without their explicit permission.
